Module cli

Module cli 

Available on crate feature cli only.

Structs

SimplexCli
An instance representing the running SimpleX CLI. Ensure to call SimplexCli::kill manually to avoid zombie/hang processes on Linux. The Drop impl tries its best to reap the process if it wasn’t killed by the user but it is not guarnteed to succeed.
SimplexCliBuilder
Builder for SimplexCli.
SimplexVersion
Parses SimpleX version numbers in the form MAJOR.MINOR.PATCH.HOTFIX.