SimplexCli

Struct SimplexCli 

pub struct SimplexCli { /* private fields */ }
Available on crate feature cli only.
An instance representing the running SimpleX CLI. Ensure to call SimplexCli::kill manually to avoid zombie/hang processes on Linux. The Drop impl tries its best to reap the process if it wasn’t killed by the user but it is not guarnteed to succeed.

Security

  • SimpleX CLI requires to pass the database key via the -k argument. On most Linux setups the -k parameter is readable from ps fx output and /proc by any user so SimplexCliBuilder::db_key doesn’t provide any meaningful security on untrusted machines

Implementations

Source

impl SimplexCli

pub fn builder( default_bot_name: impl Into<String>, port: u16, ) -> SimplexCliBuilder

Begin building a SimplexCli that will spawn a simplex-chat process.

Call SimplexCliBuilder::spawn to launch the process after configuring the builder.

pub fn port(&self) -> u16

pub fn version(&self) -> &SimplexVersion

pub async fn kill(&mut self) -> Result<()>

Kills the child process and waits for it to exit.